=======
GeoGals
=======


.. image:: https://img.shields.io/pypi/v/geogals.svg
        :target: https://pypi.python.org/pypi/geogals

.. image:: https://img.shields.io/travis/astrobenji/geogals.svg
        :target: https://travis-ci.com/astrobenji/geogals

.. image:: https://readthedocs.org/projects/geogals/badge/?version=latest
        :target: https://geogals.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A publicly available repository for using geostatistical methods on real and simulated galaxy data.


* Free software: MIT license
* Documentation: https://geogals.readthedocs.io.


Features
--------

This package contains functions that enable a user to:

 * Create a semivariogram for real or simulated spatial galaxy data
 * Fit geostatistical models to galaxy data that accounts for a spatially-varying mean, as well as small-scale fluctuations
 * Use kriging to predict values of random fields at observed/unobserved locations

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
